# eric7.Plugins.DocumentationPlugins.Ericdoc.EricdocConfigDialog

Module implementing a dialog to enter the parameters for eric7_doc.

### Global Attributes

None

### Classes

EricdocConfigDialog | Class implementing a dialog to enter the parameters for eric7_doc.

### Functions

None

## EricdocConfigDialog

Class implementing a dialog to enter the parameters for eric7_doc.

### Derived from

QDialog, Ui_EricdocConfigDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricdocConfigDialog | Constructor
__checkQtHelpOptions | Private slot to check the QtHelp options and set the ok button accordingly.
__initializeDefaults | Private method to set the default values.
__selectColor | Private method to select a color.
accept | Public slot called by the Ok button.
generateParameters | Public method that generates the commandline parameters.
on_addButton_clicked | Private slot to add the directory displayed to the listview.
on_bodyBgButton_clicked | Private slot to select the body background color.
on_bodyFgButton_clicked | Private slot to select the body foreground color.
on_cfBgButton_clicked | Private slot to select the class/function header background color.
on_cfFgButton_clicked | Private slot to select the class/function header foreground color.
on_cssPicker_pathSelected | Private slot handling the selection of a css style sheet.
on_deleteButton_clicked | Private slot to delete the currently selected directory of the listbox.
on_ignoreDirPicker_pathSelected | Private slot handling the selection of a directory to be ignored.
on_l1BgButton_clicked | Private slot to select the level 1 header background color.
on_l1FgButton_clicked | Private slot to select the level 1 header foreground color.
on_l2BgButton_clicked | Private slot to select the level 2 header background color.
on_l2FgButton_clicked | Private slot to select the level 2 header foreground color.
on_linkFgButton_clicked | Private slot to select the foreground color of links.
on_outputDirPicker_pathSelected | Private slot handling the selection of an output directory.
on_qtHelpDirPicker_pathSelected | Private slot handling the selection of the output directory for the QtHelp files.
on_qtHelpFolderEdit_textChanged | Private slot to check the virtual folder.
on_qtHelpGroup_toggled | Private slot to toggle the generation of QtHelp files.
on_qtHelpNamespaceEdit_textChanged | Private slot to check the namespace.
on_qtHelpTitleEdit_textChanged | Private slot to check the title.

### Static Methods

None

#### EricdocConfigDialog (Constructor)

EricdocConfigDialog(project, parms=None, parent=None)

Constructor

project
  reference to the project object (Project.Project)
parms
  parameters to set in the dialog
parent
  parent widget of this dialog

#### EricdocConfigDialog.__checkQtHelpOptions

__checkQtHelpOptions()

Private slot to check the QtHelp options and set the ok button accordingly.

#### EricdocConfigDialog.__initializeDefaults

__initializeDefaults()

Private method to set the default values.

These are needed later on to generate the commandline parameters.

#### EricdocConfigDialog.__selectColor

__selectColor(colorKey)

Private method to select a color.

colorKey
  key of the color to select (string)

#### EricdocConfigDialog.accept

accept()

Public slot called by the Ok button.

It saves the values in the parameters dictionary.

#### EricdocConfigDialog.generateParameters

generateParameters()

Public method that generates the commandline parameters.

It generates a list of strings to be used to set the QProcess arguments for the ericdoc call and a dictionary containing the non default parameters. This dictionary can be passed back upon object generation to overwrite the default settings.

Return:
  a tuple of the commandline parameters and non default parameters (list of strings, dictionary)

#### EricdocConfigDialog.on_addButton_clicked

on_addButton_clicked()

Private slot to add the directory displayed to the listview.

The directory in the ignore directories line edit is moved to the listbox above and the edit is cleared.

#### EricdocConfigDialog.on_bodyBgButton_clicked

on_bodyBgButton_clicked()

Private slot to select the body background color.

#### EricdocConfigDialog.on_bodyFgButton_clicked

on_bodyFgButton_clicked()

Private slot to select the body foreground color.

#### EricdocConfigDialog.on_cfBgButton_clicked

on_cfBgButton_clicked()

Private slot to select the class/function header background color.

#### EricdocConfigDialog.on_cfFgButton_clicked

on_cfFgButton_clicked()

Private slot to select the class/function header foreground color.

#### EricdocConfigDialog.on_cssPicker_pathSelected

on_cssPicker_pathSelected(path)

Private slot handling the selection of a css style sheet.

path (str)
  path of the css style sheet

#### EricdocConfigDialog.on_deleteButton_clicked

on_deleteButton_clicked()

Private slot to delete the currently selected directory of the listbox.

#### EricdocConfigDialog.on_ignoreDirPicker_pathSelected

on_ignoreDirPicker_pathSelected(path)

Private slot handling the selection of a directory to be ignored.

path (str)
  path of the directory to be ignored

#### EricdocConfigDialog.on_l1BgButton_clicked

on_l1BgButton_clicked()

Private slot to select the level 1 header background color.

#### EricdocConfigDialog.on_l1FgButton_clicked

on_l1FgButton_clicked()

Private slot to select the level 1 header foreground color.

#### EricdocConfigDialog.on_l2BgButton_clicked

on_l2BgButton_clicked()

Private slot to select the level 2 header background color.

#### EricdocConfigDialog.on_l2FgButton_clicked

on_l2FgButton_clicked()

Private slot to select the level 2 header foreground color.

#### EricdocConfigDialog.on_linkFgButton_clicked

on_linkFgButton_clicked()

Private slot to select the foreground color of links.

#### EricdocConfigDialog.on_outputDirPicker_pathSelected

on_outputDirPicker_pathSelected(path)

Private slot handling the selection of an output directory.

path (str)
  path of the output directory

#### EricdocConfigDialog.on_qtHelpDirPicker_pathSelected

on_qtHelpDirPicker_pathSelected(path)

Private slot handling the selection of the output directory for the QtHelp files.

path (str)
  path of the the output directory for the QtHelp files

#### EricdocConfigDialog.on_qtHelpFolderEdit_textChanged

on_qtHelpFolderEdit_textChanged(txt)

Private slot to check the virtual folder.

txt
  text of the line edit (string)

#### EricdocConfigDialog.on_qtHelpGroup_toggled

on_qtHelpGroup_toggled(enabled)

Private slot to toggle the generation of QtHelp files.

enabled
  flag indicating the state (boolean)

#### EricdocConfigDialog.on_qtHelpNamespaceEdit_textChanged

on_qtHelpNamespaceEdit_textChanged(txt)

Private slot to check the namespace.

txt
  text of the line edit (string)

#### EricdocConfigDialog.on_qtHelpTitleEdit_textChanged

on_qtHelpTitleEdit_textChanged(txt)

Private slot to check the title.

txt
  text of the line edit (string)

Up